==> pogamut-emohawk-ville-3.5.2-20130819.040119-107-sources.jar: cz/cuni/amis/pogamut/emohawkVille/agent/module/observationMemory/memorization/StoveMemorization.java <==
package cz.cuni.amis.pogamut.emohawkVille.agent.module.observationMemory.memorization;

import cz.cuni.amis.pogamut.emohawk.agent.module.observationMemory.IDeferredConstructor;
import cz.cuni.amis.pogamut.emohawk.agent.module.observationMemory.IDeferredConstructorChainer;
import cz.cuni.amis.pogamut.emohawk.agent.module.observationMemory.memorization.essence.AbstractEssenceMemorization;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.observationMemory.ObservationMemory;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.replication.image.IStove;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.replication.image.StoveReplication;

/** Stove memorization
 * 
 * @author Paletz
 */
public class StoveMemorization
	extends AbstractEssenceMemorization<StoveReplication>
	implements IStove {

	protected int powerLevels[] = new int[StoveReplication.PLATE_COUNT];
	protected StovePlateMemorization plates[] = new StovePlateMemorization[StoveReplication.PLATE_COUNT];
	
	public StoveMemorization(
		final StoveReplication stove,
		final ObservationMemory observationMemory,
		IDeferredConstructorChainer deferredConstructorChainer 
	) {
		super( stove, observationMemory );
		
		deferredConstructorChainer.addDeferredConstructor(
			new IDeferredConstructor() {
				@Override
				public void construct() {
					for ( int i=0; i<StoveReplication.PLATE_COUNT; ++i ) {
						powerLevels[i] = stove.getPower( i );
						plates[i] = (StovePlateMemorization) observationMemory.getMemorization( stove.getPlate(i) );
					}
				}
			}
		);
	}
	
	@Override
	public int getPower( int index ) {
		return powerLevels[index];
	}
	
	@Override
	public StovePlateMemorization getPlate(int index) {
		return plates[index];
	}
	
}

==> pogamut-emohawk-ville-3.5.4-20140114.043709-29-sources.jar: cz/cuni/amis/pogamut/emohawkVille/agent/module/observationMemory/memorization/StoveMemorization.java <==
package cz.cuni.amis.pogamut.emohawkVille.agent.module.observationMemory.memorization;

import cz.cuni.amis.pogamut.emohawk.agent.module.observationMemory.IDeferredConstructor;
import cz.cuni.amis.pogamut.emohawk.agent.module.observationMemory.IDeferredConstructorChainer;
import cz.cuni.amis.pogamut.emohawk.agent.module.observationMemory.memorization.essence.AbstractEssenceMemorization;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.observationMemory.ObservationMemory;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.replication.image.IStove;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.replication.image.StoveReplica;

/** Stove memorization
 * 
 * @author Paletz
 */
public class StoveMemorization
	extends AbstractEssenceMemorization<StoveReplica>
	implements IStove {

	protected int powerLevels[] = new int[StoveReplica.PLATE_COUNT];
	protected StovePlateMemorization plates[] = new StovePlateMemorization[StoveReplica.PLATE_COUNT];
	
	public StoveMemorization(
		final StoveReplica stove,
		final ObservationMemory observationMemory,
		IDeferredConstructorChainer deferredConstructorChainer 
	) {
		super( stove, observationMemory );
		
		deferredConstructorChainer.addDeferredConstructor(
			new IDeferredConstructor() {
				@Override
				public void construct() {
					for ( int i=0; i<StoveReplica.PLATE_COUNT; ++i ) {
						powerLevels[i] = stove.getPower( i );
						plates[i] = (StovePlateMemorization) observationMemory.getMemorization( stove.getPlate(i) );
					}
				}
			}
		);
	}
	
	@Override
	public int getPower( int index ) {
		return powerLevels[index];
	}
	
	@Override
	public StovePlateMemorization getPlate(int index) {
		return plates[index];
	}
	
}
